@@ -71,34 +71,34 @@ Addition and subtraction operations are defined for `cf.Datetime` and
 `cf.TimeDuration` objects:
 
 >>> cf.Datetime(2003, 2, 1) + cf.D(30)
-<CF Datetime: 2003-03-03T00:00:00Z>
+<CF Datetime: 2003-03-03 00:00:00>
 >>> cf.M(30) + cf.Datetime(2003, 2, 1)
-<CF Datetime: 2003-03-03T00:00:00Z>
+<CF Datetime: 2003-03-03 00:00:00>
 >>> cf.Datetime(2003, 2, 1, calendar='360_day') + cf.D(30)
-<CF Datetime: 2003-03-01T00:00:00Z 360_day>
+<CF Datetime: 2003-03-01 00:00:00 360_day>
 >>> cf.Datetime(2003, 2, 1, calendar='360_day') - cf.D(30)
-<CF Datetime: 2003-01-01T00:00:00Z 360_day>
+<CF Datetime: 2003-01-01 00:00:00 360_day>
 
 >>> cf.Datetime(2003, 2, 1) - cf.h(30)
-<CF Datetime: 2003-01-30T18:00:00Z>
+<CF Datetime: 2003-01-30 18:00:00>
 >>> cf.s(456) + cf.Datetime(2003, 2, 1)
-<CF Datetime: 2003-02-01T00:07:36Z>
+<CF Datetime: 2003-02-01 00:07:36>
 
 >>> cf.Datetime(2003, 2, 1) + cf.M(1)
-<CF Datetime: 2003-03-01T00:00:00Z>
+<CF Datetime: 2003-03-01 00:00:00>
 >>> cf.M(1) + cf.Datetime(2003, 2, 1, calendar='360_day') 
-<CF Datetime: 2003-03-01T00:00:00Z 360_day>
+<CF Datetime: 2003-03-01 00:00:00 360_day>
 >>> cf.Datetime(2003, 2, 1, calendar='noleap') + cf.M(245)
-<CF Datetime: 2023-07-01T00:00:00Z noleap>
+<CF Datetime: 2023-07-01 00:00:00 noleap>
 >>> cf.Datetime(2003, 2, 1) - cf.Y(2)
-<CF Datetime: 2001-02-01T00:00:00Z>
+<CF Datetime: 2001-02-01 00:00:00>
 >>> cf.Datetime(2003, 2, 1) - cf.Y(2) + cf.D(10)
-<CF Datetime: 2001-02-11T00:00:00Z>
+<CF Datetime: 2001-02-11 00:00:00>
 
 >>> d = cf.Datetime(2003, 2, 1)
 >>> d += cf.s(34567689)
 >>> d
-<CF Datetime: 2004-03-07T02:08:09Z>
+<CF Datetime: 2004-03-07 02:08:09>
 
 **Attributes**
 
@@ -199,9 +199,11 @@ x__str__() <==> str(x)
 
 '''   
         args = self.timetuple()[:6]
-        out = '{0: >4}-{1:0>2}-{2:0>2}T{3:0>2}:{4:0>2}:{5:0>2}Z'.format(*args)
+        out = '{0: >4}-{1:0>2}-{2:0>2} {3:0>2}:{4:0>2}:{5:0>2}Z'.format(*args)
         if self.microsecond:
-            out = out.replace('Z', '.{0:0>6}Z'.format(self.microsecond))      
+            out = out.replace('Z', '.{0:0>6}'.format(self.microsecond))      
+        else:
+            out = out.replace('Z', '')
         return out
     #--- End: def
 
@@ -345,6 +347,21 @@ d.minute, d.second, d.microsecond)``.
         return self._calendar == getattr(other, '_calendar', None)
     #--- End: def
 
+    def inspect(self):
+        '''
+
+Inspect the attributes.
+
+.. seealso:: `cf.inspect`
+
+:Returns: 
+
+    None
+
+'''
+        print cf_inspect(self)
+    #--- End: def
+
     def replace(self, year=None, month=None, day=None, hour=None,
                 minute=None, second=None, microsecond=None,
                 calendar=None):
@@ -362,15 +379,15 @@ d.minute, d.second, d.microsecond)``.
     def strftime(self, format=None):
         '''Return a string representing the date-time.
 
-The string is an ISO 8601 string of the form Y-MM-DDThh:mm:ssZ, for
-example ``2000-01-02T03:04:05Z``, or Y-MM-DDThh:mm:ss.sZ where the
+The string is an ISO 8601 string of the form Y-MM-DD hh:mm:ss, for
+example ``2000-01-02 03:04:05``, or Y-MM-DD hh:mm:ss.s where the
 final "s" refers to any sized decimal fraction added to the seconds,
-for example ``2000-01-02T03:04:05.000786Z``.
+for example ``2000-01-02 03:04:05.000786``.
 
 :Examples 1:
 
 >>> cf.Datetime(2004, 1, 30).strftime()
-'2004-01-30T00:00:00Z'
+'2004-01-30 00:00:00'
 
 :Parameters:
 
@@ -385,16 +402,16 @@ for example ``2000-01-02T03:04:05.000786Z``.
 :Examples 2:
 
 >>> cf.Datetime(2004, 2, 30).strftime()
-'2004-02-30T00:00:00Z'
+'2004-02-30 00:00:00'
 
 >>> cf.Datetime(2004, 2, 30, calendar='360_day').strftime()
-'2004-02-30T00:00:00Z'
+'2004-02-30 00:00:00'
 
 >>> cf.Datetime(2004, 7, 4, 12, 45, 56, 7456).strftime()
-'2004-07-04T12:45:56.007456Z'
+'2004-07-04 12:45:56.007456'
 
 >>> cf.Datetime(2004, 12, 34).strftime()
-'2004-12-34T00:00:00Z'
+'2004-12-34 00:00:00'
 
         '''
         return '{0: >4}-{1:0>2}-{2:0>2} {3:0>2}:{4:0>2}:{5:0>2}'.format(
@@ -410,7 +427,7 @@ Return the current Gregorian calendar UTC date and time.
 :Examples 1:
 
 >>> cf.Datetime.utcnow()
-<CF Datetime: 2016-10-10T12:15:24.002376Z>
+<CF Datetime: 2016-10-10 12:15:24.002376>
 
 :Returns:
 
@@ -420,12 +437,12 @@ Return the current Gregorian calendar UTC date and time.
 :Examples 2:
 
 >>> cf.Datetime.utcnow()
-<CF Datetime: 2016-10-10T12:15:25.422179Z>
+<CF Datetime: 2016-10-10 12:15:25.422179>
 >>> d = cf.Datetime(2005, 6, 7)
 >>> d.utcnow()
-<CF Datetime: 2016-10-10T12:15:50.375309Z>
+<CF Datetime: 2016-10-10 12:15:50.375309>
 >>> d
-<CF Datetime: 2005-06-07T00:00:00Z>
+<CF Datetime: 2005-06-07 00:00:00>
 
 '''
         return cls(*elements(datetime.utcnow()))
@@ -433,19 +450,6 @@ Return the current Gregorian calendar UTC date and time.
 
 #--- End: class
 
-#def _strftime(x):
-#    try:
-#        out = x.strftime('%Y-%m-%d %H:%M:%S')
-#    except ValueError:
-#        out = '{0}-{1:0>2}-{2:0>2} {3:0>2}:{4:0>2}:{5:0>2}'.format(
-#            *self.timetuple()[:6])
-#        
-#    if self.microsecond:
-#        out = out.replace('Z', '.{0:0>6}Z'.format(self.microsecond))
-#        
-#    return out
-
-
 #class Datetime2(object):
 #
 #    # ----------------------------------------------------------------
@@ -487,34 +491,34 @@ Return the current Gregorian calendar UTC date and time.
 #`cf.TimeDuration` objects:
 #
 #>>> cf.Datetime(2003, 2, 1) + cf.D(30)
-#<CF Datetime: 2003-03-03T00:00:00Z>
+#<CF Datetime: 2003-03-03 00:00:00>
 #>>> cf.M(30) + cf.Datetime(2003, 2, 1)
-#<CF Datetime: 2003-03-03T00:00:00Z>
+#<CF Datetime: 2003-03-03 00:00:00>
 #>>> cf.Datetime(2003, 2, 1, calendar='360_day') + cf.D(30)
-#<CF Datetime: 2003-03-01T00:00:00Z 360_day>
+#<CF Datetime: 2003-03-01 00:00:00 360_day>
 #>>> cf.Datetime(2003, 2, 1, calendar='360_day') - cf.D(30)
-#<CF Datetime: 2003-01-01T00:00:00Z 360_day>
+#<CF Datetime: 2003-01-01 00:00:00 360_day>
 #
 #>>> cf.Datetime(2003, 2, 1) - cf.h(30)
-#<CF Datetime: 2003-01-30T18:00:00Z>
+#<CF Datetime: 2003-01-30 18:00:00>
 #>>> cf.s(456) + cf.Datetime(2003, 2, 1)
-#<CF Datetime: 2003-02-01T00:07:36Z>
+#<CF Datetime: 2003-02-01 00:07:36>
 #
 #>>> cf.Datetime(2003, 2, 1) + cf.M(1)
-#<CF Datetime: 2003-03-01T00:00:00Z>
+#<CF Datetime: 2003-03-01 00:00:00>
 #>>> cf.M(1) + cf.Datetime(2003, 2, 1, calendar='360_day') 
-#<CF Datetime: 2003-03-01T00:00:00Z 360_day>
+#<CF Datetime: 2003-03-01 00:00:00 360_day>
 #>>> cf.Datetime(2003, 2, 1, calendar='noleap') + cf.M(245)
-#<CF Datetime: 2023-07-01T00:00:00Z noleap>
+#<CF Datetime: 2023-07-01 00:00:00 noleap>
 #>>> cf.Datetime(2003, 2, 1) - cf.Y(2)
-#<CF Datetime: 2001-02-01T00:00:00Z>
+#<CF Datetime: 2001-02-01 00:00:00>
 #>>> cf.Datetime(2003, 2, 1) - cf.Y(2) + cf.D(10)
-#<CF Datetime: 2001-02-11T00:00:00Z>
+#<CF Datetime: 2001-02-11 00:00:00>
 #
 #>>> d = cf.Datetime(2003, 2, 1)
 #>>> d += cf.s(34567689)
 #>>> d
-#<CF Datetime: 2004-03-07T02:08:09Z>
+#<CF Datetime: 2004-03-07 02:08:09>
 #
 #
 #**Attributes**
@@ -657,7 +661,7 @@ Return the current Gregorian calendar UTC date and time.
 #        if self.microsecond:
 #            args = list(args)
 #            args[-1] += self.microsecond/1e6            
-#        return '{0: >4}-{1:0>2}-{2:0>2}T{3:0>2}:{4:0>2}:{5:0>2}Z'.format(*args)
+#        return '{0: >4}-{1:0>2}-{2:0>2} {3:0>2}:{4:0>2}:{5:0>2}'.format(*args)
 #    #--- End: def
 #
 #    def __eq__(self, other):
@@ -1019,6 +1023,9 @@ minute, second and microsecond.
 
 :Examples:
 
+>>> d = cf.dt(2003)
+>>> print d
+'2003-2-30 00:00:00'
 >>> d = cf.dt(2003, 2, 30)
 >>> d = cf.dt(2003, 2, 30, 0, 0, 0)
 >>> d = cf.dt('2003-2-30')
