@@ -6,7 +6,7 @@ from numpy import size    as numpy_size
 
 from itertools import izip
 
-from .functions        import parse_indices
+from .functions        import parse_indices, RTOL, ATOL
 from .coordinatebounds import CoordinateBounds
 from .timeduration     import TimeDuration
 from .units            import Units
@@ -242,6 +242,11 @@ Warning: dim_name_map may be changed in place
 #        if period != other._period:
 #            return False
 
+        if atol is None:
+            atol = ATOL()        
+        if rtol is None:
+            rtol = RTOL()
+
         # Compare the data arrays
         if not super(Coordinate, self)._equivalent_data(other, rtol=rtol,
                                                         atol=atol, copy=copy):
@@ -2850,7 +2855,8 @@ False
 #ppp
     # DimensionCoordinate method
     def get_bounds(self, create=False, insert=False, bound=None,
-                   cellsize=None, flt=0.5, copy=True):
+                   cellsize=None, flt=0.5, max=None, min=None,
+                   copy=True):
         '''Get or create the cell bounds.
     
 Either return its existing bounds or, if there are none, optionally
@@ -3103,7 +3109,18 @@ create bounds based on the coordinate array values.
                 bounds_1d.append(array.item(-1,)*1.5 - array.item(-2,)*0.5)
     
                 dtype = type(bounds_1d[0])
-    
+
+                if max is not None:
+                    if self.direction():
+                        bounds_1d[-1] = max
+                    else:
+                        bounds_1d[0] = max
+                if min is not None:
+                    if self.direction():
+                        bounds_1d[0] = min
+                    else:
+                        bounds_1d[-1] = min
+                   
             else:
                 # ----------------------------------------------------
                 # Create
