@@ -1,3 +1,7 @@
+from functools import partial as functools_partial
+from itertools import izip
+from operator import mul as mul
+
 from numpy import allclose    as numpy_allclose
 from numpy import amax        as numpy_amax
 from numpy import amin        as numpy_amin
@@ -29,9 +33,7 @@ from numpy.ma import masked_where as numpy_ma_masked_where
 from numpy.ma import nomask       as numpy_ma_nomask
 from numpy.ma import where        as numpy_ma_where
 
-from functools import partial
-from itertools import izip
-from operator import mul as mul
+#from functools import partial
 
 from ..functions import broadcast_array
 
@@ -214,10 +216,10 @@ def double_precision(a):
     else:
         return a
 #    print 'DCH a.shape, a.dtype =',a.shape, a.dtype, newtype
-    try:
-        print 'a[10, 10, 10, 10] =',a[10, 10, 10, 10]
-    except:
-        pass
+#    try:
+#        print 'a[10, 10, 10, 10] =',a[10, 10, 10, 10]
+#    except:
+#        pass
 
     if numpy_ma_isMA(a):
         return a.astype(newtype)
@@ -677,28 +679,54 @@ def sum_ffinalise(out, sub_samples=None):
 #---------------------------------------------------------------------
 # Sum of weights
 #---------------------------------------------------------------------
-def sw_f(a, axis=None, masked=False, weights=None):
+def sw_f(a, axis=None, masked=False, weights=None, N=None,
+         sum_of_squares=False):
     '''
 '''
-    N = sample_size_f(a, axis=axis, masked=masked)
+    if N is None:
+        N = sample_size_f(a, axis=axis, masked=masked)
 
     if weights is not None:
-        weights = double_precision(weights)
-
         if weights.ndim < a.ndim:
             weights = broadcast_array(weights, a.shape)
 
         if masked:
             weights = numpy_ma_array(weights, mask=a.mask, copy=False)
 
+        if sum_of_squares:            
+            weights = weights * weights
+
         sw = weights.sum(axis=axis)
+    
         if not numpy_ndim(sw):
             sw = numpy_asanyarray(sw)
     else:
         sw = N.copy()
 
-    return N, sw
+    return (N, sw)
 #--- End: def
+#def sw_f(a, axis=None, masked=False, weights=None):
+#    '''
+#'''
+#    N = sample_size_f(a, axis=axis, masked=masked)
+#
+#    if weights is not None:
+#        weights = double_precision(weights)
+#
+#        if weights.ndim < a.ndim:
+#            weights = broadcast_array(weights, a.shape)
+#
+#        if masked:
+#            weights = numpy_ma_array(weights, mask=a.mask, copy=False)
+#
+#        sw = weights.sum(axis=axis)
+#        if not numpy_ndim(sw):
+#            sw = numpy_asanyarray(sw)
+#    else:
+#        sw = N.copy()
+#
+#    return N, sw
+##--- End: def
 
 sw_fpartial  = sum_fpartial
 sw_ffinalise = sum_ffinalise
@@ -706,68 +734,75 @@ sw_ffinalise = sum_ffinalise
 #---------------------------------------------------------------------
 # Sum of squares of weights
 #---------------------------------------------------------------------
-def sw2_f(a, axis=None, masked=False, weights=None):
-    '''
-'''
-    N = sample_size_f(a, axis=axis, masked=masked)
-
-    if weights is not None:
-        weights = double_precision(weights)
-
-        if weights.ndim < a.ndim:
-            weights = broadcast_array(weights, a.shape)
-            
-        if masked:                    
-            weights = numpy_ma_array(weights, mask=a.mask, copy=False)
-
-        sw2 = (weights*weights).sum(axis=axis)
-        if not numpy_ndim(sw2):
-            sw2 = numpy_asanyarray(sw2)
-    else:
-        sw2 = N.copy()
-            
-    return N, sw2
-#--- End: def
+#def sw2_f(a, axis=None, masked=False, weights=None):
+#    '''
+#'''
+#    N = sample_size_f(a, axis=axis, masked=masked)
+#
+#    if weights is not None:
+#        weights = double_precision(weights)
+#
+#        if weights.ndim < a.ndim:
+#            weights = broadcast_array(weights, a.shape)
+#            
+#        if masked:                    
+#            weights = numpy_ma_array(weights, mask=a.mask, copy=False)
+#
+#        sw2 = (weights*weights).sum(axis=axis)
+#        if not numpy_ndim(sw2):
+#            sw2 = numpy_asanyarray(sw2)
+#    else:
+#        sw2 = N.copy()
+#            
+#    return N, sw2
+##--- End: def
 
+sw2_f         = functools_partial(sw_f, sum_of_squares=True)
 sw2_fpartial  = sum_fpartial
 sw2_ffinalise = sum_ffinalise
 
 #---------------------------------------------------------------------
 # Variance
 #---------------------------------------------------------------------
-def var_f(a, axis=None, weights=None, masked=False, ddof=1, f=None):
+def var_f(a, axis=None, weights=None, masked=False, ddof=0):
     '''
 
 :Return:
-    out: 8-`tuple` of `numpy.ndarray`
+    out: `tuple`
 
 ''' 
-    a = double_precision(a)
+    weighted = weights is not None
 
-    # ----------------------------------------------------------------
-    # Find the minimum and maximum values of the weights if required
-    # ----------------------------------------------------------------
-    if not f and weights is not None and ddof:
-        if weights.ndim <= 1:
-            # Weights are 1-d
-            wmin = weights.min()
-            wmax = weights.max()
-        else:
-            # Weights have the same shape as a
-            wmin = weights.min(axis=axis)
-            wmax = weights.max(axis=axis)
-    else:
-        wmin  = None
-        wmax  = None
+   
+#    # ----------------------------------------------------------------
+#    # Find the minimum and maximum values of the weights if required
+#    # ----------------------------------------------------------------
+#    if not f and weights is not None and ddof:
+#        if weights.ndim <= 1:
+#            # Weights are 1-d
+#            wmin = weights.min()
+#            wmax = weights.max()
+#        else:
+#            # Weights have the same shape as a
+#            wmin = weights.min(axis=axis)
+#            wmax = weights.max(axis=axis)
+#    else:
+#        wmin  = None
+#        wmax  = None
 
     # ----------------------------------------------------------------
     # Methods:
     #
     # http://en.wikipedia.org/wiki/Standard_deviation#Population-based_statistics
-    # http://en.wikipedia.org/wiki/Weighted_mean#Weighted_sample_variance
+    # https://en.wikipedia.org/wiki/Weighted_arithmetic_mean#Weighted_sample_variance
     # ----------------------------------------------------------------
-    N, avg, sw = mean_f(a, weights=weights, axis=axis, masked=masked)
- 
+    N, avg, V1 = mean_f(a, weights=weights, axis=axis, masked=masked)
+
+    if weighted and ddof == 1:
+        N, V2 = sw2_f(a, axis=axis, masked=masked, weights=weights, N=N)        
+    else:
+        V2 = None
+
     if axis is not None and avg.size > 1:
         # We collapsed over a single axis and the array has 2 or more
         # axes, so add an extra size 1 axis to the mean so that
@@ -791,7 +826,7 @@ def var_f(a, axis=None, weights=None, masked=False, ddof=1, f=None):
         average = numpy_average
 
     var = average(var, axis=axis, weights=weights)
-    
+
     if reshape_avg:
         shape = avg.shape        
         avg = avg.reshape(shape[:axis] + shape[axis+1:])
@@ -799,150 +834,375 @@ def var_f(a, axis=None, weights=None, masked=False, ddof=1, f=None):
     if not numpy_ndim(var):
         var = numpy_asanyarray(var)
 
-    return N, var, avg, sw, ddof, f, wmin, wmax
+    return (N, var, avg, V1, V2, ddof, weighted)
+#--- End: def
+
+#    # ----------------------------------------------------------------
+#    # Find the minimum and maximum values of the weights if required
+#    # ----------------------------------------------------------------
+#    if not f and weights is not None and ddof:
+#        if weights.ndim <= 1:
+#            # Weights are 1-d
+#            wmin = weights.min()
+#            wmax = weights.max()
+#        else:
+#            # Weights have the same shape as a
+#            wmin = weights.min(axis=axis)
+#            wmax = weights.max(axis=axis)
+#    else:
+#        wmin  = None
+#        wmax  = None
+#
+#    # ----------------------------------------------------------------
+#    # Methods:
+#    #
+#    # http://en.wikipedia.org/wiki/Standard_deviation#Population-based_statistics
+#    # http://en.wikipedia.org/wiki/Weighted_mean#Weighted_sample_variance
+#    # ----------------------------------------------------------------
+#    N, avg, sw = mean_f(a, weights=weights, axis=axis, masked=masked)
+# 
+#    if axis is not None and avg.size > 1:
+#        # We collapsed over a single axis and the array has 2 or more
+#        # axes, so add an extra size 1 axis to the mean so that
+#        # broadcasting works when we calculate the variance.
+#        reshape_avg = True
+#        if masked:
+#            expand_dims = numpy_ma_expand_dims
+#        else:
+#            expand_dims = numpy_expand_dims
+#
+#        avg = expand_dims(avg, axis)
+#    else:
+#        reshape_avg = False
+#
+#    var  = a - avg
+#    var *= var
+#
+#    if masked:
+#        average = numpy_ma_average
+#    else:
+#        average = numpy_average
+#
+#    var = average(var, axis=axis, weights=weights)
+#    
+#    if reshape_avg:
+#        shape = avg.shape        
+#        avg = avg.reshape(shape[:axis] + shape[axis+1:])
+#
+#    if not numpy_ndim(var):
+#        var = numpy_asanyarray(var)
+#
+#    return N, var, avg, sw, ddof, f, wmin, wmax
 #--- End: def
 
 def var_fpartial(out, out1=None):
-    '''
-'''
-    N, var, avg, sw, ddof, f, wmin, wmax = out
+    '''https://en.wikipedia.org/wiki/Pooled_variance#Population-based_statistics
 
-    if out1 is None:
-        # ------------------------------------------------------------
-        # var = sw(var+avg**2)
-        # avg = sw*avg
-        # ------------------------------------------------------------
-        var += avg*avg
-        var *= sw 
-        avg *= sw 
-    else:       
-        # ------------------------------------------------------------
-        # var = var + sw1(var1+avg1**2)
-        # avg = avg + sw1*avg1
-        # sw  = sw + sw1
-        # ------------------------------------------------------------
-        N1, var1, avg1, sw1, ddof, f, wmin1, wmax1 = out1
-
-        N = psum(N, N1)
-        
-        var1 += avg1*avg1
-        var1 *= sw1
-        avg1 *= sw1
-
-        var = psum(var, var1)
-        avg = psum(avg, avg1)
-        sw  = psum(sw , sw1)
-
-        if wmin is not None:
-            wmin = pmin(wmin, wmin1)
-            wmax = pmax(wmax, wmax1)
-    #--- End: def
-
-    return N, var, avg, sw, ddof, f, wmin, wmax
-#--- End: def
-
-def var_ffinalise(out, sub_samples=None):
-    '''
 :Parameters:
 
-    out: 8-tuple of `numpy.ndarray`
+    out: `tuple`
 
-    sub_samples: `bool`, optional
+    out1: `tuple`, optional
 
 :Returns:
 
-    out: 2-tuple of `numpy.ndarray`
-
     '''
-    N, var, avg, sw, ddof, f, wmin, wmax = out
+    (N, var, avg, V1, V2, ddof, weighted) = out
+
+    if out1 is None:
+        # ------------------------------------------------------------
+        # var = V1(var+avg**2)
+        # avg = V1*avg
+        # ------------------------------------------------------------
+        var += avg*avg
+        var *= V1
+        avg *= V1
+    else:       
+        # ------------------------------------------------------------
+        # var = var + V11(var1+avg1**2)
+        # avg = avg + V11*avg1
+        # V1  = V1 + V1b
+        # V2  = V2 + V2b
+        # ------------------------------------------------------------
+        (Nb, varb, avgb, V1b, V2b, ddof, weighted) = out1
+
+        N = psum(N, Nb)
+        
+        varb += avgb*avgb
+        varb *= V1b
+        avgb *= V1b
+
+        var = psum(var, varb)
+        avg = psum(avg, avgb)
+        V1  = psum(V1 , V1b)
+
+        if weighted and ddof == 1:
+            V2 = psum(V2, V2b)
+    #--- End: def
+
+    return (N, var, avg, V1, V2, ddof, weighted)
+#--- End: def
+#def var_fpartial(out, out1=None):
+#    '''
+#'''
+#    print 'DCH var_fpartial 1'
+#    N, var, avg, sw, ddof, f, wmin, wmax = out
+#
+#    if out1 is None:
+#        print 'DCH var_fpartial 2'
+#        # ------------------------------------------------------------
+#        # var = sw(var+avg**2)
+#        # avg = sw*avg
+#        # ------------------------------------------------------------
+#        var += avg*avg
+#        var *= sw 
+#        avg *= sw 
+#    else:       
+#        print 'DCH var_fpartial 3'
+#        # ------------------------------------------------------------
+#        # var = var + sw1(var1+avg1**2)
+#        # avg = avg + sw1*avg1
+#        # sw  = sw + sw1
+#        # ------------------------------------------------------------
+#        N1, var1, avg1, sw1, ddof, f, wmin1, wmax1 = out1
+#
+#        N = psum(N, N1)
+#        
+#        var1 += avg1*avg1
+#        var1 *= sw1
+#        avg1 *= sw1
+#
+#        var = psum(var, var1)
+#        avg = psum(avg, avg1)
+#        sw  = psum(sw , sw1)
+#
+#        if wmin is not None:
+#            wmin = pmin(wmin, wmin1)
+#            wmax = pmax(wmax, wmax1)
+#    #--- End: def
+#
+#    print 'DCH var_fpartial END'
+#    return N, var, avg, sw, ddof, f, wmin, wmax
+##--- End: def
+def var_ffinalise(out, sub_samples=None):
+    '''
+https://en.wikipedia.org/wiki/Pooled_variance#Population-based_statistics
+    '''
+    (N, var, avg, V1, V2, ddof, weighted) = out
 
     N, var = mask_where_too_few_values(max(2, ddof+1), N, var)
 
     if sub_samples:
         # ----------------------------------------------------------------
-        # The global biased variance = {[SUM(psw(pv+pm**2)]/sw} - m**2        
+        # The global biased variance = {[SUM(pV1(pv+pm**2)]/V1} - m**2        
         # 
-        #   where psw = partial sum of weights
+        #   where pV1 = partial sum of weights
         #         pv  = partial biased variance 
         #         pm  = partial mean            
-        #         sw  = global sum of weights
+        #         V1  = global sum of weights
         #         m   = global mean             
         #
-        # Currently: var = SUM(psw(pv+pm**2)
-        #            avg = sw*m
+        # Currently: var = SUM(pV1(pv+pm**2)
+        #            avg = V1*m
         #
         # http://en.wikipedia.org/wiki/Standard_deviation#Population-based_statistics
         # ----------------------------------------------------------------
-        avg /= sw
+        avg /= V1
         avg *= avg
-        var /= sw
+        var /= V1
         var -= avg
     #--- End: if
 
     # ----------------------------------------------------------------
-    # var is now the global variance with sw degrees of freedom
+    # var is now the biased global variance
     # ----------------------------------------------------------------
-    if ddof:
-        if f:
-            sw *= f
-        elif wmin is not None:
-           # ---------------------------------------------------------
-           # The global variance is weighted and needs to be
-           # calculated with greater than 0 delta degrees of
-           # freedom. The sum of weights (sw) needs to be adjusted:
-           #
-           # sw = f*sw (approximately!)
-           # 
-           # where f = smallest positive number whose products with
-           #           the smallest and largest weights and the sum of
-           #           weights are all integers
-           # ---------------------------------------------------------
-           wmin = wmin.astype(float)
-           wmax = wmax.astype(float)
-           sw   = sw.astype(float)
-           
-           wmax /= wmin
-           sw   /= wmin
-           
-           if (not numpy_allclose(wmax, wmax.astype(int), rtol=1e-05, atol=1e-08) or
-               not numpy_allclose(sw  , sw.astype(int)  , rtol=1e-05, atol=1e-08)):
-           
-               m = numpy_zeros(wmax.shape, dtype=int)            
-               n = 2
-               while True:
-                   nwmax = n*wmax
-                   nsw   = n*sw
-                   ccc = (m == 0)
-                   ccc &= numpy.isclose(nwmax, nwmax.astype(int), rtol=1e-05, atol=1e-08)
-                   ccc &= numpy.isclose(nsw  , nsw.astype(int)  , rtol=1e-05, atol=1e-08)
-                   m = numpy_where(ccc, n, m)
-#                   print 'DCH rase', m.min()
-                   if m.min():
-                       # Every element of m has been set (to an integer
-                       # greater than 1), so we are done.
-                       break                
-                   
-                   # Some elements of m have not been set, so try the
-                   # next multiplier.
-                   n += 1
-               #--- End: while
-               sw *= m
-           #--- End: if
-        #--- End: if
-    
-        # ------------------------------------------------------------
-        # Adjust the variance for fewer than sw degrees of freedom:
+    if not weighted:
+        if ddof:
+            # The unweighted variance with N-ddof degrees of freedom is
+            # [V1/(V1-ddof)]*var. In this case V1 equals the sample size,
+            # N. ddof=1 provides an unbiased estimator of the variance of
+            # a hypothetical infinite population.            
+            V1 /= V1 - ddof
+            var *= V1
+    elif ddof == 1:
+        # Calculate the weighted unbiased variance. The unbiased
+        # variance weighted with _reliability_ weights is
+        # [V1**2/(V1**2-V2)]*var.
         #
-        # var = var*sw/(sw-ddof)
-        # ------------------------------------------------------------
-        var *= sw
-        sw -= ddof
-        var /= sw
+        # https://en.wikipedia.org/wiki/Weighted_arithmetic_mean#Weighted_sample_variance
+        V1 **= 2
+        var *= V1
+        V1 -= V2
+        var /= V1
+    elif ddof:
+        raise ValueError(
+"Can only calculate a weighted variance with 0 or 1 delta degrees of freedom: ddof={}".format(
+    ddof))
+
+
+#    if ddof:
+#        if f:
+#            sw *= f
+#        elif wmin is not None:
+#           # ---------------------------------------------------------
+#           # The global variance is weighted and needs to be
+#           # calculated with greater than 0 delta degrees of
+#           # freedom. The sum of weights (sw) needs to be adjusted:
+#           #
+#           # sw = f*sw (approximately!)
+#           # 
+#           # where f = smallest positive number whose products with
+#           #           the smallest and largest weights and the sum of
+#           #           weights are all integers
+#           # ---------------------------------------------------------
+#           wmin = wmin.astype(float)
+#           wmax = wmax.astype(float)
+#           sw   = sw.astype(float)
+#           
+#           wmax /= wmin
+#           sw   /= wmin
+#           
+#           if (not numpy_allclose(wmax, wmax.astype(int), rtol=1e-05, atol=1e-08) or
+#               not numpy_allclose(sw  , sw.astype(int)  , rtol=1e-05, atol=1e-08)):
+#           
+#               m = numpy_zeros(wmax.shape, dtype=int)            
+#               n = 2
+#               while True:
+#                   nwmax = n*wmax
+#                   nsw   = n*sw
+#                   ccc = (m == 0)
+#                   ccc &= numpy.isclose(nwmax, nwmax.astype(int), rtol=1e-05, atol=1e-08)
+#                   ccc &= numpy.isclose(nsw  , nsw.astype(int)  , rtol=1e-05, atol=1e-08)
+#                   m = numpy_where(ccc, n, m)
+#                   if m.min():
+#                       # Every element of m has been set (to an integer
+#                       # greater than 1), so we are done.
+#                       break                
+#                   
+#                   # Some elements of m have not been set, so try the
+#                   # next multiplier.
+#                   n += 1
+#               #--- End: while
+#               sw *= m
+#           #--- End: if
+#        #--- End: if
+#    
+#        # ------------------------------------------------------------
+#        # Adjust the variance for fewer than sw degrees of freedom:
+#        #
+#        # var = var*sw/(sw-ddof)
+#        # ------------------------------------------------------------
+#        var *= sw
+#        sw -= ddof
+#        var /= sw
     #--- End: if
 
     return N, var
 #--- End: def
 
+#def var_ffinalise(out, sub_samples=None):
+#    '''
+#:Parameters:
+#
+#    out: 8-tuple of `numpy.ndarray`
+#
+#    sub_samples: `bool`, optional
+#
+#:Returns:
+#
+#    out: 2-tuple of `numpy.ndarray`
+#
+#    '''
+#    N, var, avg, sw, ddof, f, wmin, wmax = out
+#
+#    N, var = mask_where_too_few_values(max(2, ddof+1), N, var)
+#
+#    if sub_samples:
+#        # ----------------------------------------------------------------
+#        # The global biased variance = {[SUM(psw(pv+pm**2)]/sw} - m**2        
+#        # 
+#        #   where psw = partial sum of weights
+#        #         pv  = partial biased variance 
+#        #         pm  = partial mean            
+#        #         sw  = global sum of weights
+#        #         m   = global mean             
+#        #
+#        # Currently: var = SUM(psw(pv+pm**2)
+#        #            avg = sw*m
+#        #
+#        # http://en.wikipedia.org/wiki/Standard_deviation#Population-based_statistics
+#        # ----------------------------------------------------------------
+#        avg /= sw
+#        avg *= avg
+#        var /= sw
+#        var -= avg
+#    #--- End: if
+#
+#    # ----------------------------------------------------------------
+#    # var is now the global variance with sw degrees of freedom
+#    # ----------------------------------------------------------------
+#    if ddof:
+#        print 'DCH in ddof'
+#        if f:
+#            sw *= f
+#        elif wmin is not None:
+#           # ---------------------------------------------------------
+#           # The global variance is weighted and needs to be
+#           # calculated with greater than 0 delta degrees of
+#           # freedom. The sum of weights (sw) needs to be adjusted:
+#           #
+#           # sw = f*sw (approximately!)
+#           # 
+#           # where f = smallest positive number whose products with
+#           #           the smallest and largest weights and the sum of
+#           #           weights are all integers
+#           # ---------------------------------------------------------
+#           wmin = wmin.astype(float)
+#           wmax = wmax.astype(float)
+#           sw   = sw.astype(float)
+#           
+#           wmax /= wmin
+#           sw   /= wmin
+#           
+#           if (not numpy_allclose(wmax, wmax.astype(int), rtol=1e-05, atol=1e-08) or
+#               not numpy_allclose(sw  , sw.astype(int)  , rtol=1e-05, atol=1e-08)):
+#           
+#               m = numpy_zeros(wmax.shape, dtype=int)            
+#               n = 2
+#               while True:
+#                   nwmax = n*wmax
+#                   nsw   = n*sw
+#                   ccc = (m == 0)
+#                   ccc &= numpy.isclose(nwmax, nwmax.astype(int), rtol=1e-05, atol=1e-08)
+#                   ccc &= numpy.isclose(nsw  , nsw.astype(int)  , rtol=1e-05, atol=1e-08)
+#                   m = numpy_where(ccc, n, m)
+#                   print 'DCH m.min() =', m.min()
+#                   if m.min():
+#                       # Every element of m has been set (to an integer
+#                       # greater than 1), so we are done.
+#                       break                
+#                   
+#                   # Some elements of m have not been set, so try the
+#                   # next multiplier.
+#                   n += 1
+#               #--- End: while
+#               sw *= m
+#           #--- End: if
+#        #--- End: if
+#    
+#        # ------------------------------------------------------------
+#        # Adjust the variance for fewer than sw degrees of freedom:
+#        #
+#        # var = var*sw/(sw-ddof)
+#        # ------------------------------------------------------------
+#        var *= sw
+#        sw -= ddof
+#        var /= sw
+#    #--- End: if
+#
+#    return N, var
+##--- End: def
+
 #---------------------------------------------------------------------
 # Standard deviation
 #---------------------------------------------------------------------
