@@ -599,7 +599,8 @@ Return a deep copy.
     def dataarray(self, axes=None, flip=None, units=None,
                   revert_to_file=False, hardmask=True, dtype=None,
                   readonly=False, copy_regardless=False,
-                  func=None, update=True, keep_in_memory=True):
+                  func=_Units_conform, update=True, keep_in_memory=True):
+#                  func=None, update=True, keep_in_memory=True):
         '''
 
 Returns the partition's data array.
@@ -767,17 +768,19 @@ otherwise a memory leak could occur. For example:
         # another partition is referencing this numpy array), even if
         # the units are already correct.
         # ------------------------------------------------------------
-        if func is None:
+#        if func is None:
+        if func is _Units_conform:
             if not p_units.equals(units) and bool(p_units) is bool(units):
-                func = _Units_conform
+#                func = _Units_conform
                 if (not unique or not update or
                     not p_data.flags['C_CONTIGUOUS'] or p_data.dtype.kind == 'i'):
                     inplace = False
                 else:
                     inplace = True
+            else:
+                func = None
         else:
              inplace = update and unique
-        #--- End: if
 
         if func is not None:
             p_data  = func(p_data, p_units, units, inplace)
@@ -882,11 +885,11 @@ True
 True
 
 '''
-#        return False
-        if self.Units.isreftime and self.subarray.dtype == _dtype_object:
-            return True
-        else:
-            return False
+        return self.Units.isreftime and self.subarray.dtype == _dtype_object
+#        if self.Units.isreftime and self.subarray.dtype == _dtype_object:
+#            return True
+#        else:
+#            return False
     #--- End: def
 
     def file_close(self):
