@@ -43,7 +43,8 @@ def write(fields, filename, fmt='NETCDF3_CLASSIC', overwrite=True,
           least_significant_digit=None, endian='native', compress=0,
           fletcher32=False, no_shuffle=False, datatype=None,
           single=False, double=False, reference_datetime=None,
-          variable_attributes=None, HDF_chunks=None, unlimited=None):
+          variable_attributes=None, HDF_chunks=None, unlimited=None,
+          _debug=False):
     '''Write fields to a CF-netCDF or CFA-netCDF file.
     
 NetCDF dimension and variable names will be taken from variables'
@@ -344,6 +345,7 @@ and auxiliary coordinate roles for different data variables.
          # Miscellaneous
          # -----------------------------------------------------------
          'verbose': verbose,
+         '_debug' : _debug,
     }
 
     if fmt == 'CFA3':
@@ -1428,6 +1430,7 @@ then the input coordinate is not written.
     if not _seen(coord, (), g=g):
         ncvar, g['scalarN'] = _variable_ncvar(coord, 'scalar', g['scalarN'],
                                               g=g)
+
         # If this scalar coordinate has bounds then create the
         # bounds netCDF variable and add the bounds or climatology
         # attribute to the dictionary of extra attributes
@@ -1499,7 +1502,7 @@ then the input coordinate is not written.
     
     else:
         ncvar, g['auxN'] = _variable_ncvar(coord, 'aux', g['auxN'], g=g)
-        
+
         # If this auxiliary coordinate has bounds then create the
         # bounds netCDF variable and add the bounds or climatology
         # attribute to the dictionary of extra attributes
@@ -1711,9 +1714,14 @@ created. The ``seen`` dictionary is updated for *cfvar*.
     None
 
 '''
+    _debug = g['_debug']
+
     if g['verbose']:
         print repr(cfvar)+' netCDF: '+ncvar
 
+    if _debug:
+        print '        '+repr(cfvar)+' netCDF: '+ncvar
+
     # Set the netCDF4.createVariable datatype
     datatype = _datatype(cfvar, g=g)
     ncdimensions = dimensions
@@ -1875,6 +1883,9 @@ message+". Unlimited dimension must be the first (leftmost) dimension of the var
             if data.fits_in_one_chunk_in_memory(data.dtype.itemsize):
                 data.varray
 
+            if _debug:
+                print "        g['nc']['"+ncvar+"'].shape =", g['nc'][ncvar].shape
+                
             for partition in data.partitions.flat:
                 array = partition.dataarray(**pda_args)   
 
@@ -1896,6 +1907,10 @@ message+". Unlimited dimension must be the first (leftmost) dimension of the var
 "ERROR: Can't write field when array has _FillValue or missing_value at unmasked point: {0!r}".format(
     cfvar))
 
+                if _debug:
+                    print '            partition.indices =', partition.indices
+                    print '            array.shape       =', array.shape
+                    
                 # Copy the array into the netCDF variable
                 g['nc'][ncvar][partition.indices] = array
 
@@ -1937,6 +1952,9 @@ def _write_a_field(f, add_to_seen=False, allow_data_expand_dims=True,
     None
 
 '''
+    if g['_debug']:
+        print '    Field:', repr(f)
+        
     seen = g['seen']
       
     if add_to_seen:
