@@ -389,15 +389,15 @@ Office (UK) fields files format files may be read.
                 n, _plural(n)))
     #--- End: if
 
-    # ----------------------------------------------------------------
-    # Add standard names to UM fields
-    # ----------------------------------------------------------------
-    for f in field_list:
-        standard_name = getattr(f, '_standard_name', None)
-        if standard_name is not None:
-            f.standard_name = standard_name
-            del f._standard_name
-    #--- End: for
+#    # ----------------------------------------------------------------
+#    # Add standard names to UM fields
+#    # ----------------------------------------------------------------
+#    for f in field_list:
+#        standard_name = getattr(f, '_standard_name', None)
+#        if standard_name is not None:
+#            f.standard_name = standard_name
+#            del f._standard_name
+#    #--- End: for
 
     # ----------------------------------------------------------------
     # Squeeze size one dimensions from the data arrays. Do one of:
@@ -521,7 +521,7 @@ Read the contents of a single file into a field list.
         
     elif ftype == 'UM' and (selected_fmt in (None, 'PP', 'FF')):
         fields = um_read(filename, um_version=umversion,
-                         verbose=verbose, set_standard_name=False,
+                         verbose=verbose, set_standard_name=True,
                          height_at_top_of_model=height_at_top_of_model,
                          fmt=fmt, word_size=word_size, endian=endian)
 
