@@ -854,11 +854,16 @@ x.__rmod__(y) <==> y % x
     def _offset(self, dt):
         '''
 
+:Parameters:
+
+    dt: `cf.Datetime`
+
+:Returns:
 .. versionadded:: 1.4
         '''
         return Datetime(*[(i if j is None else j)
                           for i, j in zip(elements(dt), self.offset)],
-                        calendar=getattr(dt, 'calendar', None))
+                        calendar=getattr(dt, '_calendar', None))
     #--- End: def        
 
     # ----------------------------------------------------------------
@@ -1537,6 +1542,7 @@ consistent with the time duration's offset.
         '''
         abs_self = abs(self)
         dt0 = self._offset(dt)
+
         if dt0 > dt:
             dt1 = dt0
             dt0 = dt1 - abs_self
