@@ -5,7 +5,8 @@ from .umread.umfile import File, UMFileException
 
 _file_to_UM = _file_to_fh.setdefault('UM', {})
 
-def _open_um_file(filename, aggregate=True, fmt=None, word_size=None, endian=None):
+def _open_um_file(filename, aggregate=True, fmt=None, word_size=None,
+                  byte_ordering=None):
     '''Open a UM fields file or PP file and read it into a
 `umread.umfile.File` object.
 
@@ -42,14 +43,9 @@ is returned with an open file descriptor.
         # Close a random data array file to make way for this one
         close_one_file()
 
-    if endian:
-        byte_ordering = endian+'_endian'
-    else:        
-        byte_ordering = None
-
     try:  
-        f = File(filename, byte_ordering=byte_ordering, word_size=word_size,
-                 format=fmt)
+        f = File(filename, byte_ordering=byte_ordering,
+                 word_size=word_size, format=fmt)
     except Exception as error:
         try:
             f.close_fd()
