@@ -36,7 +36,7 @@ if __name__ == '__main__':
     print 'CF-PYTHON TEST SUITE'
     print '--------------------'
     print 'Run date:', datetime.datetime.now()
-    cf.ENVIRONMENT()
+    cf.environment()
     print ''
 
     cf.CHUNKSIZE(original_chunksize)
