@@ -34,7 +34,7 @@ class DataTest(unittest.TestCase):
 #    test_only = ('test_Data_any',)
 #    test_only = ('test_Data_mean',)
 #    test_only = ('test_Data_sums_of_weights',)
-    test_only = ['test_Data_sd_var']
+#    test_only = ['test_Data_sd_var']
 #    test_only = ('test_Data_sd_var',)
 #    test_only = ['test_Data_max_min_sum']
 #    test_only = ('test_Data___setitem__',)
