@@ -24,7 +24,7 @@ class QueryTest(unittest.TestCase):
         for chunksize in self.chunk_sizes:    
             cf.CHUNKSIZE(chunksize)
             d = cf.Data([[1., 5.], [6, 2]], 'days since 2000-12-29 21:57:57')   
-            self.assertTrue((d==cf.eq(cf.dt('2001-01-03 21:57:57'))).equals(cf.Data([[False, True], [False, False]])))
+            self.assertTrue((d==cf.eq(cf.dt('2001-01-03 21:57:57'))).equals(cf.Data([[False, True], [False, False]])), repr((d==cf.eq(cf.dt('2001-01-03 21:57:57'))).array))
             self.assertTrue((d==cf.ne(cf.dt('2001-01-03 21:57:57'))).equals(cf.Data([[True, False], [True, True]])))
             self.assertTrue((d==cf.ge(cf.dt('2001-01-03 21:57:57'))).equals(cf.Data([[False, True], [True, False]])))
             self.assertTrue((d==cf.gt(cf.dt('2001-01-03 21:57:57'))).equals(cf.Data([[False, False], [True, False]])))
@@ -69,7 +69,7 @@ class QueryTest(unittest.TestCase):
         for chunksize in self.chunk_sizes:    
             cf.CHUNKSIZE(chunksize)
             d = cf.Data([[1., 5.], [6, 2]], 'days since 2000-12-29 21:57:57')   
-            self.assertTrue((d==cf.dteq('2001-01-03 21:57:57')).equals(cf.Data([[False, True], [False, False]])))
+            self.assertTrue((d==cf.dteq('2001-01-03 21:57:57')).equals(cf.Data([[False, True], [False, False]])), d.dtarray)
             self.assertTrue((d==cf.dtne('2001-01-03 21:57:57')).equals(cf.Data([[True, False], [True, True]])))
             self.assertTrue((d==cf.dtge('2001-01-03 21:57:57')).equals(cf.Data([[False, True], [True, False]])))
             self.assertTrue((d==cf.dtgt('2001-01-03 21:57:57')).equals(cf.Data([[False, False], [True, False]])))
