@@ -50,24 +50,24 @@ class RegridTest(unittest.TestCase):
             f1 = cf.read(self.filename1)
             f2 = cf.read(self.filename2)
             f3 = cf.read(self.filename3)
-            self.assertTrue(f3.equals(f1.regrids(f2, axis_order='ZT'), traceback=True),
+            self.assertTrue(f3.equals(f1.regrids(f2), traceback=True),
                             'destination = global Field, CHUNKSIZE = %s' % chunksize)
-            self.assertTrue(f3.equals(f1.regrids(f2, axis_order='ZT', method='conservative'),
+            self.assertTrue(f3.equals(f1.regrids(f2, method='conservative'),
                                       traceback=True),
                             'destination = global Field, CHUNKSIZE = %s' % chunksize)
             dst = {'longitude': f2.dim('X'), 'latitude': f2.dim('Y')}
-            self.assertTrue(f3.equals(f1.regrids(dst, dst_cyclic=True, axis_order='ZT'),
+            self.assertTrue(f3.equals(f1.regrids(dst, dst_cyclic=True),
                                       traceback=True),
                             'destination = global dict, CHUNKSIZE = %s' % chunksize)
             self.assertTrue(f3.equals(f1.regrids(dst, method='conservative',
-                                                 dst_cyclic=True, axis_order='ZT'),
+                                                 dst_cyclic=True),
                                       traceback=True),
                             'destination = global dict, CHUNKSIZE = %s' % chunksize)
             f4 = cf.read(self.filename4)
             f5 = cf.read(self.filename5)
-            self.assertTrue(f4.equals(f1.regrids(f5, axis_order='ZT'), traceback=True),
+            self.assertTrue(f4.equals(f1.regrids(f5), traceback=True),
                             'destination = regional Field, CHUNKSIZE = %s' % chunksize)
-            self.assertTrue(f4.equals(f1.regrids(f5, method='bilinear', axis_order='ZT'),
+            self.assertTrue(f4.equals(f1.regrids(f5, method='bilinear'),
                                       traceback=True),
                             'destination = regional Field, CHUNKSIZE = %s' % chunksize)
         #--- End: for
@@ -88,7 +88,8 @@ class RegridTest(unittest.TestCase):
             f1 = cf.read(self.filename7)
             f2 = cf.read(self.filename8)
             f3 = cf.read(self.filename9)
-            self.assertTrue(f3.equals(f1.regridc(f2, axes='T', method='bilinear'), traceback=True),
+            self.assertTrue(f3.equals(f1.regridc(f2, axes='T', method='bilinear'),
+                                      traceback=True),
                             'destination = time series, CHUNKSIZE = %s' % chunksize)
             f4 = cf.read(self.filename1)
             f5 = cf.read(self.filename2)
